@@ -1,3 +1,4 @@
+from edc_constants.disease_constants import THERAPEUTIC_PL
 from edc_reportable import (
     MILLIGRAMS_PER_DECILITER,
     MILLIMOLES_PER_LITER,
@@ -6,8 +7,6 @@ from edc_reportable import (
     MM3_DISPLAY,
 )
 
-from .constants import THERAPEUTIC_PL
-
 LP_REASON = (
     ("scheduled_per_protocol", "Scheduled per protocol"),
     (THERAPEUTIC_PL, "Therapeutic LP"),
